/**
 * 
 */
package org.arabicfedora;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * This class models a POFile having a header in one chunck and a list of messages.
 * 
 * @author Mohammad Ghoniem
 */
public class POFile {
	private String header = null;	// header data in one chunck
	private List data = null;	// po message data

	/**
	 * Default constructor with empty header and message list.
	 */
	public POFile(){
		this("", new ArrayList());
	}
	
	public POFile(String header, ArrayList data){
		this.header = header;
		this.data = data;
	}
	
	public void appendToHeader(String str){
		header+=(header.length()>0)?("\n"+str):str;
	}
	
	/**
	 * Adds a message to the message list.
	 * 
	 * @param message
	 */
	public void addMessage(POMessage message){
		data.add(message);
	}

	public List getData() {
		return data;
	}

	public void setData(List data) {
		this.data = new ArrayList(data);
	}

	public String getHeader() {
		return header;
	}

	public void setHeader(String header) {
		this.header = header;
	}
	
	/**
	 * @return an Iterator in order to traverse the message list.
	 */
	public Iterator messageIterator(){
		return data.iterator();
	}
	
	/**
	 * Resets the header and data relative to the current instance of POFile.
	 */
	public void clear(){
		this.header = "";
		this.data.clear();
	}
	
	/**
	 * Prints the header and messages contained in this POFile.
	 *
	 */
	public void print(){
		System.out.println(this.toString());
	}
	
	/**
	 * 	Returns a string representation of the current POFile. 
	 */
	public String toString(){
		String result = this.getHeader()+"\n";
		for(Iterator iter = this.messageIterator(); iter.hasNext();)
			result+=((POMessage)iter.next()).toString()+"\n";
		return result;
	}
}
