/**
 * 
 */
package org.arabicfedora.io;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;

import org.arabicfedora.POFile;
import org.arabicfedora.POMessage;

/**
 * This class is responsible for loading a PO file into a POFile instance. 
 * It can take any charset name documented in  java.nio.charset.Charset.
 * 
 * @author Mohammad Ghoniem
 */
public class POFileLoader {
	
	private String charsetName = "UTF-8"; 	// default encoding is set to UTF-8, 
											//check class Charset for other possiblities
	private POFile pofile = null;
	
	public POFileLoader(){
		pofile = new POFile();
	}
	
	public void load(File file){
		this.pofile.clear();
		System.out.print("Start parsing...");
		try{
			FileInputStream fis = new FileInputStream(file);
			InputStreamReader isr = new InputStreamReader(fis, charsetName);
			BufferedReader reader = new BufferedReader(isr);
			
			String line = reader.readLine();
			String id = null;
			String str = null;
			String comments = "";
			String header = "";

			int start, end = -1;
			while(line!=null){
				System.out.print(".");
				// retrieves comments or header data
				if (line.startsWith("#")){

					if(line.startsWith("#:") ||line.startsWith("#,"))
						comments+=(comments.length()>0)?("\n"+line):line;
					else
						header+=(header.length()>0)?("\n"+line):line;

				}
				// retrieves original strings
				else if(line.startsWith("msgid")){
					start = line.indexOf("\"");
					end = line.lastIndexOf("\"");
					id = line.substring(start+1,end);
					start = -1;
					end = -1;
				}
				// retrieves translated strings
				else if(line.startsWith("msgstr")){
					start = line.indexOf("\"");
					end = line.lastIndexOf("\"");
					str = line.substring(start+1,end);
					start = -1;
					end = -1;
					// sets up a POMessage instance and stores it
					if(id!=null && str != null && comments.length() !=0){
						pofile.addMessage(new POMessage(id.intern(), str.intern(), comments.intern()));
						id = null;
						str = null;
						comments = "";
					}
				}
				line = reader.readLine();
			}
			// stores header data
			pofile.setHeader(header);
			System.out.println("\nDone.");
		}catch(IOException ioe){
			ioe.printStackTrace();
		}
	}
	
	public void print(){
		pofile.print();
	}

	/**
	 * @see java.nio.charset.Charset
	 * @return
	 */
	public String getCharsetName() {
		return charsetName;
	}

	/**
	 * @see java.nio.charset.Charset
	 * @param charsetName
	 */
	public void setCharsetName(String charsetName) {
		this.charsetName = charsetName;
	}
	

	public POFile getPofile() {
		return pofile;
	}

	public void setPofile(POFile pofile) {
		this.pofile = pofile;
	}
		
}
